%define dav_user %{name}
%define dav_group %{name}
%define dav_localstatedir /run
%define dav_syscachedir /var/cache

Summary:	File system driver that allows you to mount a WebDAV server
Name:		davfs2
Version:	1.7.0
Release:	%mkrel 2
License:	GPLv3+
Group:		System/Kernel and hardware
URL:		https://savannah.nongnu.org/projects/davfs2
Source0:	http://ftp.twaren.net/Unix/NonGNU/%{name}/%{name}-%{version}.tar.gz
Source1:	%{name}.tmpfiles.conf
Patch1:		segfault.patch
Requires(pre):	filesystem >= 2.1.9-18
Requires(post):	systemd >= %{systemd_required_version}
Requires(pre):	rpm-helper
Requires(postun): rpm-helper
BuildRequires:	pkgconfig(neon) >= 0.27
BuildRequires:	gettext-devel >= 0.14.4
BuildRequires:	libtool
BuildRequires:	mercurial
Provides:	davfs = %{version}-%{release}
Obsoletes:	davfs < 0.2.5

%description
davfs2 is a Linux file system driver that allows you to mount a WebDAV server
as a local file system, like a disk drive. This way applications can access
resources on a Web server without knowing anything about HTTP or WebDAV. davfs2
runs as a daemon in userspace. It uses the kernel file system coda or fuse.
Most probably your Linux kernel includes at least one of this file systems. To
connect to the WebDAV server it makes use of the neon library. Neon supports
TLS/SSL (using OpenSSL or GnuTLS) and access via proxy server.

davfs2 allows you to e.g.

 * use a WebDAV server as workspace for a geographically distributed work
   group.
 * save documents on a WebDAV server and access and edit them via internet from
   wherever you want.
 * edit a web site in place, using your preferred development tools.


%prep
%autosetup -S hg

%build
autoreconf -vfi

export dav_user=%{dav_user}
export dav_group=%{dav_group}
export dav_localstatedir=%{dav_localstatedir}
export dav_syscachedir=%{dav_syscachedir}
export CFLAGS="%{optflags} -fcommon"

%configure \
    --disable-rpath \

%make_build

%install
install -d %{buildroot}%{dav_syscachedir}/%{name}
install -d %{buildroot}%{_datadir}/%{name}

%make_install

# (cg) For some reason install puts stuff here...
rm -rf %{buildroot}/sbin

# rename the binaries
ln -s %{_sbindir}/mount.davfs %{buildroot}%{_sbindir}/mount.%{name}
ln -s %{_sbindir}/umount.davfs %{buildroot}%{_sbindir}/umount.%{name}

# create tmpfiles directory
install -D -p -m 0644 %{SOURCE1} %{buildroot}%{_tmpfilesdir}/%{name}.conf

# rename the manpages
find %{buildroot}%{_mandir} -name "*.gz" | xargs gunzip

%find_lang %{name} --all-name

%pre
%_pre_useradd %{dav_user} %{dav_localstatedir}/mount.%{name} /bin/false

%post
%_tmpfilescreate %{name}

%postun
%_postun_userdel %{dav_user}

%files -f %{name}.lang
%doc %{_docdir}/%{name}
%exclude %{_docdir}/%{name}/INSTALL
%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/certs
%dir %{_sysconfdir}/%{name}/certs/private
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/secrets
%{_sbindir}/mount.davfs*
%{_sbindir}/umount.davfs*
%{_tmpfilesdir}/%{name}.conf
%{_mandir}/man5/*
%{_mandir}/man8/*
%lang(de) %{_mandir}/de/man5/*
%lang(de) %{_mandir}/de/man8/*
%lang(es) %{_mandir}/es/man5/*
%attr(1775,root,%{dav_group}) %dir %{dav_syscachedir}/%{name}
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*


%changelog
* Wed May 17 2023 mokraemer <mokraemer> 1.7.0-2.mga9
+ Revision: 1957123
- patching segfault, slow access (mga#31702)

* Sat Nov 19 2022 joequant <joequant> 1.7.0-1.mga9
+ Revision: 1909098
- update to 1.7.0

* Sat Mar 19 2022 umeabot <umeabot> 1.6.0-2.mga9
+ Revision: 1800018
- Mageia 9 Mass Rebuild

* Sun Aug 30 2020 shlomif <shlomif> 1.6.0-1.mga8
+ Revision: 1619737
- New version 1.6.0

* Sat Jun 27 2020 joequant <joequant> 1.5.6-3.mga8
+ Revision: 1599630
- redo
- fix gcc10 build

* Tue Feb 18 2020 umeabot <umeabot> 1.5.6-2.mga8
+ Revision: 1541489
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Dec 28 2019 daviddavid <daviddavid> 1.5.6-1.mga8
+ Revision: 1474546
- new version: 1.5.6

* Fri Mar 15 2019 shlomif <shlomif> 1.5.5-1.mga7
+ Revision: 1377657
- New version 1.5.5

* Sun Sep 23 2018 umeabot <umeabot> 1.5.4-2.mga7
+ Revision: 1297405
- Mageia 7 Mass Rebuild

* Mon Jul 11 2016 shlomif <shlomif> 1.5.4-1.mga6
+ Revision: 1041166
- New version 1.5.4 w some important/security fixes

* Sun Feb 14 2016 umeabot <umeabot> 1.5.2-4.mga6
+ Revision: 959837
- Mageia 6 Mass Rebuild

* Wed Oct 28 2015 joequant <joequant> 1.5.2-3.mga6
+ Revision: 895959
- fix docdir

* Tue Oct 27 2015 daviddavid <daviddavid> 1.5.2-2.mga6
+ Revision: 895750
- update doc file list to fix build with latest rpm

* Sun Dec 07 2014 shlomif <shlomif> 1.5.2-1.mga5
+ Revision: 801822
- New version 1.5.2

* Wed Oct 15 2014 umeabot <umeabot> 1.4.7-8.mga5
+ Revision: 748786
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.7-7.mga5
+ Revision: 678675
- Mageia 5 Mass Rebuild

* Wed Apr 02 2014 wally <wally> 1.4.7-6.mga5
+ Revision: 611330
- add patch to fix build with new libneon

* Mon Oct 21 2013 umeabot <umeabot> 1.4.7-5.mga4
+ Revision: 537777
- Mageia 4 Mass Rebuild

* Fri Sep 27 2013 oden <oden> 1.4.7-4.mga4
+ Revision: 487669
- P0: security fix for CVE-2013-4362 (debian)

* Sun Mar 24 2013 colin <colin> 1.4.7-3.mga3
+ Revision: 405136
- Use tmpfiles macros and add system version to requires (mga#9302)

* Fri Jan 11 2013 umeabot <umeabot> 1.4.7-2.mga3
+ Revision: 348623
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Aug 07 2012 sander85 <sander85> 1.4.7-1.mga3
+ Revision: 279812
- New version: 1.4.7

* Sat Jul 21 2012 colin <colin> 1.4.6-2.mga3
+ Revision: 273158
- Update for usrmove

* Tue Mar 08 2011 ennael <ennael> 1.4.6-1.mga1
+ Revision: 66438
- imported package davfs2

